# ALISE privacy policy and description

## Description of the service

The Account LInking SErvice (ALISE) provides a layer where identities, enrollment, group membership and other attributes and authorization policies on distributed resources can be managed in an homogeneous way. In particular, the ALISE acts as a central service for authentication and authorization management for linked accounts.

## Processed data

### The following attributes are requested from the OIDC-Provider server:

    - Name
    - Email
    - Entitlements
    - Affiliation
    - Unique Identifier

## Purpose for the processing of personal data

The ALISE service provides a Token Translation Service for authorised users. In order to provide a service, personal data and log files are collected and used for:

    - User authentication and authorization at the service or at trusted services
    - Automated sending of email messages necessary for the use of the service
    - Statistics and development of the service
    - Integration testing

## Regular disclosure of personal data to third parties

Personal data is not regularly disclosed to third parties.

## Data retention

In general, personal data is not stored for more than four weeks after a user terminated their account.

The user may ask to be removed from the service by interacting with the contact person for the service. Access logs are deleted after 12 months.

## Transfer of personal data outside the EU or EEA

Personal data shall not be transferred to any third party outside the EU.

## How to access, rectify and delete the personal data

Contact for the service is provided. To rectify the data released by a Home Organisation, contact the Home Organisation's operators.

## Data protection code of conduct

Personal data will be protected according to the Code of Conduct for Service Providers, a common standard for the research and higher education sector to protect the user's privacy.

## Contact Information

KIT/SCC

Dr. Marcus Hardt

Herrmann-von-Helmholtz-Platz 1

76344 Eggenstein-Leopoldshafen

m-ops@lists.kit.edu

## KIT Helpdesk:

http://www.scc.kit.edu/servicedesk/index.php